ListTableMetadataInput

Struct ListTableMetadataInput 

#[non_exhaustive]
pub struct ListTableMetadataInput { pub catalog_name: Option<String>, pub database_name: Option<String>, pub expression: Option<String>, pub next_token: Option<String>, pub max_results: Option<i32>, pub work_group: Option<String>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
catalog_name: Option<String>

The name of the data catalog for which table metadata should be returned.

database_name: Option<String>

The name of the database for which table metadata should be returned.

expression: Option<String>

A regex filter that pattern-matches table names. If no expression is supplied, metadata for all tables are listed.

next_token: Option<String>

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.

max_results: Option<i32>

Specifies the maximum number of results to return.

work_group: Option<String>

The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.

Implementations

Source

impl ListTableMetadataInput

pub fn catalog_name(&self) -> Option<&str>

The name of the data catalog for which table metadata should be returned.

pub fn database_name(&self) -> Option<&str>

The name of the database for which table metadata should be returned.

pub fn expression(&self) -> Option<&str>

A regex filter that pattern-matches table names. If no expression is supplied, metadata for all tables are listed.

pub fn next_token(&self) -> Option<&str>

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.

pub fn max_results(&self) -> Option<i32>

Specifies the maximum number of results to return.

pub fn work_group(&self) -> Option<&str>

The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.

Source

impl ListTableMetadataInput

pub fn builder() -> ListTableMetadataInputBuilder

Creates a new builder-style object to manufacture ListTableMetadataInput.