#[non_exhaustive]pub struct ListTableMetadataOutput {
pub table_metadata_list: Option<Vec<TableMetadata>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.table_metadata_list: Option<Vec<TableMetadata>>A list of table metadata.
next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Implementations
Sourceimpl ListTableMetadataOutput
impl ListTableMetadataOutput
Sourcepub fn table_metadata_list(&self) -> &[TableMetadata]
pub fn table_metadata_list(&self) -> &[TableMetadata]
A list of table metadata.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .table_metadata_list.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourceimpl ListTableMetadataOutput
impl ListTableMetadataOutput
Sourcepub fn builder() -> ListTableMetadataOutputBuilder
pub fn builder() -> ListTableMetadataOutputBuilder
Creates a new builder-style object to manufacture ListTableMetadataOutput.